package
Version:
v0.0.0-...-89bf0d2
Opens a new window with list of versions in this module.
Published: Oct 23, 2018
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
NewController initializes our songs controller.
type Spec struct {
Year int `json:"year"`
Album string `json:"album"`
Genre string `json:"genre"`
}
Spec represents our song data
Source Files
¶
Click to show internal directories.
Click to hide internal directories.